@@ -50,11 +50,11 @@ void *myrealloc(void *p, size_t n)
 extern int sys_nerr;
 extern char *sys_errlist[];
 
-char *strerror(int errno)
+char *strerror(int err)
 {
-  assert(errno>=0);
-  assert(errno<sys_nerr);
-  return sys_errlist[errno];
+  assert(err>=0);
+  assert(err<sys_nerr);
+  return sys_errlist[err];
 }
 /*}}}*/
 #endif
