@@ -17,6 +17,11 @@ implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 #ifdef BROKEN_REALLOC
 #define realloc(p,s) myrealloc(p,s)
+extern void *myrealloc(void *p, size_t n);
+#endif
+
+#ifndef HAVE_STRERROR
+extern char *strerror(int err);
 #endif
 
 #ifndef _POSIX_PATH_MAX
