@@ -28,6 +28,6 @@ with this program.  If not, write to the Free Software Foundation, Inc.,
 #include <stdio.h>
 
 int endingInPossesiveS(const char *s, size_t length);
-void sentence(const char *cmd, FILE *in, const char *file, void (*process)(const char *, size_t, const char *, int), const char *lang);
+void sentence(const char *cmd, FILE *in, const char *file, void (*process)(const char *, size_t, const char *, int, int, int, int), const char *lang);
 
 #endif
