@@ -846,7 +846,7 @@ static struct Hit lengths;
  * @param str sentence
  * @param length its length
  */
-static void style(const char *str, size_t length, const char *file, int line) /*{{{*/
+static void style(const char *str, size_t length, const char *file, int line, int col, int endLine, int endCol) /*{{{*/
 {
   int firstWord=1;
   int inword=0;
@@ -979,7 +979,7 @@ static void style(const char *str, size_t length, const char *file, int line) /*
   if ((printLongSentences && sentWords>=printLongSentences) 
       || (printARI && ari(sentLetters,sentWords,1)>printARI)
       || (printPassiveSentences && passive)
-      || (printNomSentences && nom)) printf("%s:%d: %s\n",file,line,str);
+      || (printNomSentences && nom)) printf("%s:%d.%d-%d.%d: %s\n",file,line,col,endLine,endCol,str);
 }
 /*}}}*/
 
@@ -1183,12 +1183,12 @@ word usage:
         printf(_("        verb types:\n"));
         printf(_("        to be (%d) auxiliary (%d) \n"), tobeVerbs, auxVerbs);
         printf(_("        types as %% of total:\n"));
-        printf(_("        conjunctions %1.f% (%d) pronouns %1.f% (%d) prepositions %1.f% (%d)\n"), 
+        printf(_("        conjunctions %1.f%% (%d) pronouns %1.f%% (%d) prepositions %1.f%% (%d)\n"), 
                 (100.0*(conjunctions+subConjunctions))/words, 
                 conjunctions+subConjunctions, 
                 (100.0*pronouns)/words, pronouns, (100.0*prepositions)/words,
                 prepositions);
-        printf(_("        nominalizations %1.f% (%d)\n"),
+        printf(_("        nominalizations %1.f%% (%d)\n"),
                 (100.0*nominalizations)/words, nominalizations);
 
         printf(_("sentence beginnings:\n"));
